Build doughnut geometries from a list of sf data frames
doughnut_builder.RdThis function takes a list of sf data frames representing progressively buffered geometries
and returns a new sf object where each row contains a doughnut-shaped geometry
(i.e., the difference between successive buffers). This